@@ -6,7 +6,9 @@ import torch.nn.functional as F
 import math
 from torch.autograd import Variable
 import torch.utils.model_zoo as model_zoo
-from UNet import *
+from UNet.dataloader import *
+from UNet.model import *
+from UNet.train import *
 from UNetPP import *
 from PointNet import *
 from StackGAN import *
@@ -14,10 +16,8 @@ from CharCNN import *
 from PSPNet import *
 from Inpainting import *
 from AdapAttnIC import *
-import requests
 
 device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')
-# model_weights = {UNet : }
 def models(name = None):
     if name is None:
         return "No Models loaded"
@@ -36,17 +36,21 @@ def UNet(num_channels = 1, pretrained = False):        # num_channels = 1 if gra
         print("Model Loaded Succesfully") 
     return model
 
-def UNetPP(num_channels = 1, pretrained = False):      # num_channels = 1 if grayscale image else num_channels = 3 if color image
-    if pretrained == True:
+def UNetPP(num_channels = 1, pretrained = False, train = False):      # num_channels = 1 if grayscale image else num_channels = 3 if color image
+    if train == False:    
+        if pretrained == True:
+            model = UNet_PP(num_channels, DenseBlock, BasicDownBlock, BasicUpBlock)
+            url = "https://github.com/Vinayak-VG/ModelZoo_PyPi/releases/download/Weights/U-Net++.pt"    
+            checkpoint = model_zoo.load_url(url, map_location=device)
+            model.load_state_dict(checkpoint['model_state_dict'])
+            print("Pre-Trained Model Loaded Succesfully")
+        else:    
+            model = UNet_PP(num_channels, DenseBlock, BasicDownBlock, BasicUpBlock)
+            print("Model Loaded Succesfully") 
+        return model
+    else:
         model = UNet_PP(num_channels, DenseBlock, BasicDownBlock, BasicUpBlock)
-        url = "https://github.com/Vinayak-VG/ModelZoo_PyPi/releases/download/Weights/U-Net++.pt"    
-        checkpoint = model_zoo.load_url(url, map_location=device)
-        model.load_state_dict(checkpoint['model_state_dict'])
-        print("Pre-Trained Model Loaded Succesfully")
-    else:    
-        model = UNet_PP(num_channels, DenseBlock, BasicDownBlock, BasicUpBlock)
-        print("Model Loaded Succesfully") 
-    return model
+        UNet_Train()
 
 def PointNet(pretrained = False):
     if pretrained == True:
